currentSession property
HosteDaySession?
get
currentSession
Returns the active authenticated session, or null when signed out.
Implementation
HosteDaySession? get currentSession => _currentSession;
Returns the active authenticated session, or null when signed out.
HosteDaySession? get currentSession => _currentSession;