Hosteday class abstract final

Backward-compatible alias for the old Hosteday API.

Deprecated: use HosteDay in all new code.

Annotations
  • @Deprecated('Use HosteDay instead. ' 'This compatibility class will be removed in a future major version.')

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

auth HosteDayAuth
no setter
client HosteDayClient
no setter
config HosteDayConfig
no setter
http → HosteDayHttpClient
no setter
instance HosteDayClient
no setter
isInitialized bool
no setter
isInitializing bool
no setter
realtime HosteDayRealtimeClient
no setter

Static Methods

connectRealtime() Future<void>
disconnectRealtime() Future<void>
dispose() Future<void>
initializeApp({required Map<String, Object?> options, HosteDayTokenProvider? tokenProvider, HosteDayAuthStorage? authStorage, bool connectRealtime = false}) Future<HosteDayClient>