HostedayUserCredential class

Returned after a successful Hosteday authentication operation.

Constructors

HostedayUserCredential({required HostedayUser user, required HostedaySession session, required bool isNewUser})
Creates a Hosteday authentication result.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNewUser → bool
Indicates whether this credential originated from registration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → HostedaySession
The newly created authenticated session.
final
user → HostedayUser
The authenticated user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited